@@ -76,6 +76,9 @@ var searchData=
   ['libinput_5fdevice_5fref',['libinput_device_ref',['../group__device.html#ga3335d55a50f0c2fb0c5f496a3105d467',1,'libinput.h']]],
   ['libinput_5fdevice_5fset_5fseat_5flogical_5fname',['libinput_device_set_seat_logical_name',['../group__device.html#ga9f76acc43c8684a13f232073ee829b50',1,'libinput.h']]],
   ['libinput_5fdevice_5fset_5fuser_5fdata',['libinput_device_set_user_data',['../group__device.html#ga6243ad6005b2ce2a5ecfd1b04787fe93',1,'libinput.h']]],
+  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5fbuttons',['libinput_device_tablet_pad_get_num_buttons',['../group__device.html#ga2c5a5703982bcedc71a0470278258710',1,'libinput.h']]],
+  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5frings',['libinput_device_tablet_pad_get_num_rings',['../group__device.html#ga624cd4cb5fcd049fe88b2ab5f0a649cb',1,'libinput.h']]],
+  ['libinput_5fdevice_5ftablet_5fpad_5fget_5fnum_5fstrips',['libinput_device_tablet_pad_get_num_strips',['../group__device.html#gaa0696b32b500ccc0876396a184e22c01',1,'libinput.h']]],
   ['libinput_5fdevice_5funref',['libinput_device_unref',['../group__device.html#ga857340e2dab06c7f7d84173a5a1fa427',1,'libinput.h']]],
   ['libinput_5fdispatch',['libinput_dispatch',['../group__base.html#ga271f910ed17461830e48d4cd20483a00',1,'libinput.h']]],
   ['libinput_5fevent_5fdestroy',['libinput_event_destroy',['../group__event.html#ga1df956c16e26cbbd911e553ec081022a',1,'libinput.h']]],
@@ -97,6 +100,7 @@ var searchData=
   ['libinput_5fevent_5fget_5fgesture_5fevent',['libinput_event_get_gesture_event',['../group__event.html#gae173f30b70c265036bbdc9557f3115c4',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fkeyboard_5fevent',['libinput_event_get_keyboard_event',['../group__event.html#ga8378f8fdd01e8afbcea8ddbb5411570d',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5fpointer_5fevent',['libinput_event_get_pointer_event',['../group__event.html#ga52acdc3afcf75efeb8153f50eef20615',1,'libinput.h']]],
+  ['libinput_5fevent_5fget_5ftablet_5fpad_5fevent',['libinput_event_get_tablet_pad_event',['../group__event.html#gaf5677182e32138bda352cc37b03dec07',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5ftablet_5ftool_5fevent',['libinput_event_get_tablet_tool_event',['../group__event.html#gadfd7d9f1c3210f394faa60928f3c187f',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5ftouch_5fevent',['libinput_event_get_touch_event',['../group__event.html#gad2cba8252024bdcc341499bedd3d0be7',1,'libinput.h']]],
   ['libinput_5fevent_5fget_5ftype',['libinput_event_get_type',['../group__event.html#ga430a3a7369afd6c5ff722179327df79a',1,'libinput.h']]],
@@ -124,6 +128,17 @@ var searchData=
   ['libinput_5fevent_5fpointer_5fget_5ftime',['libinput_event_pointer_get_time',['../group__event__pointer.html#gac42d0e19d076f4e1fca15f1ec42510d5',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fget_5ftime_5fusec',['libinput_event_pointer_get_time_usec',['../group__event__pointer.html#gaf0997d730299f40dbe3efcfa06c429be',1,'libinput.h']]],
   ['libinput_5fevent_5fpointer_5fhas_5faxis',['libinput_event_pointer_has_axis',['../group__event__pointer.html#ga1fdd37a49eae958aaf78a0596cd5cef5',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbase_5fevent',['libinput_event_tablet_pad_get_base_event',['../group__event__tablet.html#ga33eb585eb7da3f35c083084a1f4e5586',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbutton_5fnumber',['libinput_event_tablet_pad_get_button_number',['../group__event__tablet.html#ga4339cf54b0a511599595e8483eea360d',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fbutton_5fstate',['libinput_event_tablet_pad_get_button_state',['../group__event__tablet.html#ga92235cd641c3003f18c0cb5bbf2e3c88',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fnumber',['libinput_event_tablet_pad_get_ring_number',['../group__event__tablet.html#gae866be98b773edcf95ad9a36b5bbacb1',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fposition',['libinput_event_tablet_pad_get_ring_position',['../group__event__tablet.html#ga77526f6732ae51aaab3973a69239a25e',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fring_5fsource',['libinput_event_tablet_pad_get_ring_source',['../group__event__tablet.html#ga96102ae975b4a28f0a02d035dd11496d',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fnumber',['libinput_event_tablet_pad_get_strip_number',['../group__event__tablet.html#ga32792a10d7f86900a4f94e63037f68b6',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fposition',['libinput_event_tablet_pad_get_strip_position',['../group__event__tablet.html#gaeff6c2c21b2b02e4d2f9b0b23db27dea',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5fstrip_5fsource',['libinput_event_tablet_pad_get_strip_source',['../group__event__tablet.html#ga9dded037d0f4dbfc9ffa67795118c431',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5ftime',['libinput_event_tablet_pad_get_time',['../group__event__tablet.html#ga126efe81b0c73a14ac71419ee5683f1b',1,'libinput.h']]],
+  ['libinput_5fevent_5ftablet_5fpad_5fget_5ftime_5fusec',['libinput_event_tablet_pad_get_time_usec',['../group__event__tablet.html#ga86dc23306e80986a819e3764a9847108',1,'libinput.h']]],
   ['libinput_5fevent_5ftablet_5ftool_5fdistance_5fhas_5fchanged',['libinput_event_tablet_tool_distance_has_changed',['../group__event__tablet.html#ga161c5a254417ed5527beadcdf1bdc55c',1,'libinput.h']]],
   ['libinput_5fevent_5ftablet_5ftool_5fget_5fbase_5fevent',['libinput_event_tablet_tool_get_base_event',['../group__event__tablet.html#ga90299b56480264cf775c871e52526bb9',1,'libinput.h']]],
   ['libinput_5fevent_5ftablet_5ftool_5fget_5fbutton',['libinput_event_tablet_tool_get_button',['../group__event__tablet.html#gae36ab2ab73d8b7f00da4cc33f22699ef',1,'libinput.h']]],
