@@ -231,7 +231,7 @@ tablet_update_tool(struct tablet_dispatch *tablet,
 }
 
 static inline double
-normalize_dist_slider(const struct input_absinfo *absinfo)
+normalize_slider(const struct input_absinfo *absinfo)
 {
 	double range = absinfo->maximum - absinfo->minimum;
 	double value = (absinfo->value - absinfo->minimum) / range;
@@ -239,6 +239,15 @@ normalize_dist_slider(const struct input_absinfo *absinfo)
 	return value * 2 - 1;
 }
 
+static inline double
+normalize_distance(const struct input_absinfo *absinfo)
+{
+	double range = absinfo->maximum - absinfo->minimum;
+	double value = (absinfo->value - absinfo->minimum) / range;
+
+	return value;
+}
+
 static inline double
 normalize_pressure(const struct input_absinfo *absinfo,
 		   struct libinput_tablet_tool *tool)
@@ -420,7 +429,7 @@ tablet_handle_distance(struct tablet_dispatch *tablet,
 	if (bit_is_set(tablet->changed_axes,
 		       LIBINPUT_TABLET_TOOL_AXIS_DISTANCE)) {
 		absinfo = libevdev_get_abs_info(device->evdev, ABS_DISTANCE);
-		tablet->axes.distance = normalize_dist_slider(absinfo);
+		tablet->axes.distance = normalize_distance(absinfo);
 	}
 
 	return tablet->axes.distance;
@@ -435,7 +444,7 @@ tablet_handle_slider(struct tablet_dispatch *tablet,
 	if (bit_is_set(tablet->changed_axes,
 		       LIBINPUT_TABLET_TOOL_AXIS_SLIDER)) {
 		absinfo = libevdev_get_abs_info(device->evdev, ABS_WHEEL);
-		tablet->axes.slider = normalize_dist_slider(absinfo);
+		tablet->axes.slider = normalize_slider(absinfo);
 	}
 
 	return tablet->axes.slider;
@@ -1606,45 +1615,9 @@ tablet_init_accel(struct tablet_dispatch *tablet, struct evdev_device *device)
 static void
 tablet_init_left_handed(struct evdev_device *device)
 {
-#if HAVE_LIBWACOM
-	struct libinput *libinput = device->base.seat->libinput;
-	WacomDeviceDatabase *db;
-	WacomDevice *d = NULL;
-	WacomError *error;
-	const char *devnode;
-
-	db = libwacom_database_new();
-	if (!db) {
-		log_info(libinput,
-			 "Failed to initialize libwacom context.\n");
-		return;
-	}
-	error = libwacom_error_new();
-	devnode = udev_device_get_devnode(device->udev_device);
-
-	d = libwacom_new_from_path(db,
-				   devnode,
-				   WFALLBACK_NONE,
-				   error);
-
-	if (d) {
-		if (libwacom_is_reversible(d))
+	if (evdev_tablet_has_left_handed(device))
 		    evdev_init_left_handed(device,
 					   tablet_change_to_left_handed);
-	} else if (libwacom_error_get_code(error) == WERROR_UNKNOWN_MODEL) {
-		log_info(libinput, "Tablet unknown to libwacom\n");
-	} else {
-		log_error(libinput,
-			  "libwacom error: %s\n",
-			  libwacom_error_get_message(error));
-	}
-
-	if (error)
-		libwacom_error_free(&error);
-	if (d)
-		libwacom_destroy(d);
-	libwacom_database_destroy(db);
-#endif
 }
 
 static int
