@@ -568,7 +568,11 @@ get_key_type(uint16_t code)
 		return EVDEV_KEY_TYPE_BUTTON;
 	if (code >= KEY_OK && code <= KEY_LIGHTS_TOGGLE)
 		return EVDEV_KEY_TYPE_KEY;
-	if (code >= BTN_DPAD_UP && code <= BTN_TRIGGER_HAPPY40)
+	if (code >= BTN_DPAD_UP && code <= BTN_DPAD_RIGHT)
+		return EVDEV_KEY_TYPE_BUTTON;
+	if (code >= KEY_ALS_TOGGLE && code <= KEY_KBDINPUTASSIST_CANCEL)
+		return EVDEV_KEY_TYPE_KEY;
+	if (code >= BTN_TRIGGER_HAPPY && code <= BTN_TRIGGER_HAPPY40)
 		return EVDEV_KEY_TYPE_BUTTON;
 	return EVDEV_KEY_TYPE_NONE;
 }
