@@ -61,6 +61,7 @@ enum evdev_device_seat_capability {
 	EVDEV_DEVICE_KEYBOARD = (1 << 1),
 	EVDEV_DEVICE_TOUCH = (1 << 2),
 	EVDEV_DEVICE_TABLET = (1 << 3),
+	EVDEV_DEVICE_TABLET_PAD = (1 << 4),
 	EVDEV_DEVICE_GESTURE = (1 << 5),
 };
 
@@ -114,11 +115,13 @@ enum evdev_device_model {
 	EVDEV_MODEL_CYAPA = (1 << 15),
 	EVDEV_MODEL_ALPS_RUSHMORE = (1 << 16),
 	EVDEV_MODEL_LENOVO_T450_TOUCHPAD= (1 << 17),
+	EVDEV_MODEL_WOBBLY_TOUCHPAD = (1 << 18),
 };
 
 struct mt_slot {
 	int32_t seat_slot;
 	struct device_coords point;
+	struct device_coords hysteresis_center;
 };
 
 struct evdev_device {
@@ -152,6 +155,8 @@ struct evdev_device {
 		int slot;
 		struct mt_slot *slots;
 		size_t slots_len;
+		bool want_hysteresis;
+		struct device_coords hysteresis_margin;
 	} mt;
 	struct mtdev *mtdev;
 
@@ -172,6 +177,7 @@ struct evdev_device {
 		/* Checks if buttons are down and commits the setting */
 		void (*change_scroll_method)(struct evdev_device *device);
 		bool button_scroll_active;
+		bool button_scroll_btn_pressed;
 		double threshold;
 		double direction_lock_threshold;
 		uint32_t direction;
@@ -317,6 +323,9 @@ evdev_mt_touchpad_create(struct evdev_device *device);
 struct evdev_dispatch *
 evdev_tablet_create(struct evdev_device *device);
 
+struct evdev_dispatch *
+evdev_tablet_pad_create(struct evdev_device *device);
+
 void
 evdev_tag_touchpad(struct evdev_device *device,
 		   struct udev_device *udev_device);
@@ -367,6 +376,15 @@ evdev_device_has_button(struct evdev_device *device, uint32_t code);
 int
 evdev_device_has_key(struct evdev_device *device, uint32_t code);
 
+int
+evdev_device_tablet_pad_get_num_buttons(struct evdev_device *device);
+
+int
+evdev_device_tablet_pad_get_num_rings(struct evdev_device *device);
+
+int
+evdev_device_tablet_pad_get_num_strips(struct evdev_device *device);
+
 double
 evdev_device_transform_x(struct evdev_device *device,
 			 double x,
@@ -397,7 +415,7 @@ evdev_keyboard_notify_key(struct evdev_device *device,
 void
 evdev_pointer_notify_button(struct evdev_device *device,
 			    uint64_t time,
-			    int button,
+			    unsigned int button,
 			    enum libinput_button_state state);
 void
 evdev_pointer_notify_physical_button(struct evdev_device *device,
@@ -454,6 +472,9 @@ int
 evdev_init_left_handed(struct evdev_device *device,
 		       void (*change_to_left_handed)(struct evdev_device *));
 
+bool
+evdev_tablet_has_left_handed(struct evdev_device *device);
+
 static inline uint32_t
 evdev_to_left_handed(struct evdev_device *device,
 		     uint32_t button)
@@ -467,4 +488,17 @@ evdev_to_left_handed(struct evdev_device *device,
 	return button;
 }
 
+static inline int
+evdev_hysteresis(int in, int center, int margin)
+{
+	int diff = in - center;
+	if (abs(diff) <= margin)
+		return center;
+
+	if (diff > margin)
+		return center + diff - margin;
+	else
+		return center + diff + margin;
+}
+
 #endif /* EVDEV_H */
